@@ -19,7 +19,6 @@
 { package Net::Server::MSVA;
   use strict;
   use base qw(Net::Server::Fork);
-  use Net::Server 2.000 ();
 
   my $msva;
   # guarantee initial failure -- this will be cleared after we bind
@@ -33,16 +32,6 @@
     $msva->post_bind_hook($self, @_);
   }
 
-  sub pre_loop_hook {
-    my $self = shift;
-    $msva->pre_loop_hook($self, @_);
-  }
-
-  sub pre_accept_hook {
-    my $self = shift;
-    $msva->pre_accept_hook($self, @_);
-  }
-
   sub set_exit_status {
     my $self = shift;
     $exit_status = shift;
